import { AnyObject, DataObject, Model } from '@loopback/repository';
import { RequestContext } from '@loopback/rest';
import { IAuthUserWithPermissions, ILogger, SuccessResponse } from '@sourceloop/core';
import { AuthClient, User } from '../../../models';
import { AuthCodeGeneratorFn, CodeReaderFn, JWTSignerFn, JWTVerifierFn, JwtPayloadFn } from '../../../providers';
import { AuthClientRepository, LoginActivityRepository, OtpCacheRepository, RefreshTokenRepository, RevokedTokenRepository, RoleRepository, TenantConfigRepository, UserCredentialsRepository, UserLevelPermissionRepository, UserLevelResourceRepository, UserRepository, UserTenantRepository } from '../../../repositories';
import { LoginHelperService } from '../../../services';
import { ActorId, IUserActivity, UserValidationFn } from '../../../types';
import { AuthRefreshTokenRequest, AuthTokenRequest, AuthUser, LoginRequest, ResetPassword, TokenResponse } from '../models';
import { CodeResponse } from '../types';
export declare class LoginController {
    private readonly client;
    private readonly user;
    authClientRepository: AuthClientRepository;
    userRepo: UserRepository;
    otpCacheRepo: OtpCacheRepository;
    roleRepo: RoleRepository;
    utPermsRepo: UserLevelPermissionRepository;
    userResourcesRepository: UserLevelResourceRepository;
    userTenantRepo: UserTenantRepository;
    refreshTokenRepo: RefreshTokenRepository;
    revokedTokensRepo: RevokedTokenRepository;
    tenantConfigRepo: TenantConfigRepository;
    userCredsRepository: UserCredentialsRepository;
    logger: ILogger;
    private readonly getJwtPayload;
    private readonly loginHelperService;
    private readonly getAuthCode;
    private readonly jwtSigner;
    private readonly loginActivityRepo;
    private readonly actorKey;
    private readonly ctx;
    private userValidationProvider;
    private readonly jwtVerifier;
    private readonly userActivity?;
    constructor(client: AuthClient | undefined, user: AuthUser | undefined, authClientRepository: AuthClientRepository, userRepo: UserRepository, otpCacheRepo: OtpCacheRepository, roleRepo: RoleRepository, utPermsRepo: UserLevelPermissionRepository, userResourcesRepository: UserLevelResourceRepository, userTenantRepo: UserTenantRepository, refreshTokenRepo: RefreshTokenRepository, revokedTokensRepo: RevokedTokenRepository, tenantConfigRepo: TenantConfigRepository, userCredsRepository: UserCredentialsRepository, logger: ILogger, getJwtPayload: JwtPayloadFn, loginHelperService: LoginHelperService, getAuthCode: AuthCodeGeneratorFn, jwtSigner: JWTSignerFn<object>, loginActivityRepo: LoginActivityRepository, actorKey: ActorId, ctx: RequestContext, userValidationProvider: UserValidationFn, jwtVerifier: JWTVerifierFn<AnyObject>, userActivity?: IUserActivity | undefined);
    login(req: LoginRequest, client: AuthClient | undefined, user: AuthUser | undefined): Promise<CodeResponse>;
    loginWithClientUser(req: LoginRequest): Promise<TokenResponse>;
    getToken(req: AuthTokenRequest, codeReader: CodeReaderFn): Promise<TokenResponse>;
    exchangeToken(req: AuthRefreshTokenRequest, deviceId?: string, token?: string): Promise<TokenResponse>;
    resetPassword(req: ResetPassword, auth: string, currentUser: IAuthUserWithPermissions): Promise<SuccessResponse>;
    getPasswordResponse(userName: string, password: string, prevPassword?: string): Promise<User<DataObject<Model>>>;
    me(): Promise<AuthUser | undefined>;
    switchToken(req: AuthRefreshTokenRequest): Promise<TokenResponse>;
    private createTokenPayload;
    private createJWT;
    private markUserActivity;
}
