import { AnyObject } from '@loopback/repository';
import { ILogger } from '@sourceloop/core';
import { CodeReaderFn, CodeWriterFn, JWTVerifierFn, MfaCheckFn } from '../../../providers';
import { AuthClientRepository, OtpCacheRepository, UserCredentialsRepository, UserRepository } from '../../../repositories';
import { IMfaConfig, IOtpConfig } from '../../../types';
import { AuthTokenRequest, AuthUser, OtpLoginRequest, OtpSendRequest } from '../models';
import { CodeResponse, QrCodeCheckResponse, QrCodeCreateResponse } from '../types';
export declare class OtpController {
    authClientRepository: AuthClientRepository;
    userRepo: UserRepository;
    otpCacheRepo: OtpCacheRepository;
    userCredsRepository: UserCredentialsRepository;
    logger: ILogger;
    private readonly checkMfa;
    private readonly jwtVerifier;
    private readonly mfaConfig;
    private readonly otpConfig;
    constructor(authClientRepository: AuthClientRepository, userRepo: UserRepository, otpCacheRepo: OtpCacheRepository, userCredsRepository: UserCredentialsRepository, logger: ILogger, checkMfa: MfaCheckFn, jwtVerifier: JWTVerifierFn<AnyObject>, mfaConfig: IMfaConfig, otpConfig: IOtpConfig);
    sendOtp(req: OtpSendRequest): Promise<void>;
    verifyOtp(req: OtpLoginRequest, user: AuthUser, codeWriter: CodeWriterFn): Promise<CodeResponse>;
    checkQr(code: string, clientId: string, codeReader: CodeReaderFn): Promise<QrCodeCheckResponse>;
    createQr(req: AuthTokenRequest, codeReader: CodeReaderFn): Promise<QrCodeCreateResponse>;
}
