"use strict";
var _a, _b, _c, _d;
Object.defineProperty(exports, "__esModule", { value: true });
exports.SamlLoginController = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const providers_1 = require("../../../providers");
const repositories_1 = require("../../../repositories");
const models_1 = require("../models");
let SamlLoginController = class SamlLoginController {
    constructor(authClientRepository, logger, getAuthCode) {
        this.authClientRepository = authClientRepository;
        this.logger = logger;
        this.getAuthCode = getAuthCode;
    }
    async postLoginViaSaml(clientCreds) {
        //do nothing
    }
    async oktaSamlCallback(user, request, clientId, response, oktaData) {
        if (!clientId || !user) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* AuthErrorKeys.ClientInvalid */);
        }
        const client = await this.authClientRepository.findOne({
            where: {
                clientId,
            },
        });
        if (!(client === null || client === void 0 ? void 0 : client.redirectUrl)) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* AuthErrorKeys.ClientInvalid */);
        }
        try {
            const token = await this.getAuthCode(client, user);
            response.redirect(`${client.redirectUrl}?code=${token}`);
        }
        catch (error) {
            this.logger.error(error);
            throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
    }
};
exports.SamlLoginController = SamlLoginController;
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticateClient)("client-password" /* STRATEGY.CLIENT_PASSWORD */),
    (0, loopback4_authentication_1.authenticate)("saml" /* STRATEGY.SAML */, {
        accessType: 'offline',
        scope: ['profile', 'email'],
        callbackURL: process.env.SAML_CALLBACK_URL,
        issuer: process.env.SAML_ISSUER,
        cert: process.env.SAML_CERT,
        entryPoint: process.env.SAML_ENTRY_POINT,
        audience: process.env.SAML_AUDIENCE,
        logoutUrl: process.env.SAML_LOGOUT_URL,
        passReqToCallback: !!+((_a = process.env.SAML_AUTH_PASS_REQ_CALLBACK) !== null && _a !== void 0 ? _a : 0),
        validateInResponseTo: !!+((_b = process.env.VALIDATE_RESPONSE) !== null && _b !== void 0 ? _b : 1),
        idpIssuer: process.env.IDP_ISSUER,
        logoutCallbackUrl: process.env.SAML_LOGOUT_CALLBACK_URL,
    }),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/auth/saml', {
        description: 'POST Call for saml based login',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Saml Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { [core_1.X_TS_TYPE]: models_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.FORM_URLENCODED]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.ClientAuthRequest),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.ClientAuthRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], SamlLoginController.prototype, "postLoginViaSaml", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("saml" /* STRATEGY.SAML */, {
        accessType: 'offline',
        scope: ['profile', 'email'],
        issuer: process.env.SAML_ISSUER,
        callbackURL: process.env.SAML_CALLBACK_URL,
        cert: process.env.SAML_CERT,
        entryPoint: process.env.SAML_ENTRY_POINT,
        audience: process.env.SAML_AUDIENCE,
        logoutUrl: process.env.SAML_LOGOUT_URL,
        passReqToCallback: !!+((_c = process.env.SAML_AUTH_PASS_REQ_CALLBACK) !== null && _c !== void 0 ? _c : 0),
        validateInResponseTo: !!+((_d = process.env.VALIDATE_RESPONSE) !== null && _d !== void 0 ? _d : 1),
        idpIssuer: process.env.IDP_ISSUER,
        logoutCallbackUrl: process.env.SAML_LOGOUT_CALLBACK_URL,
    }),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)(`/auth/saml-redirect`, {
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'okta auth callback',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { [core_1.X_TS_TYPE]: models_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, (0, context_1.inject)(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(1, (0, context_1.inject)(rest_1.RestBindings.Http.REQUEST)),
    tslib_1.__param(2, rest_1.param.query.string('client')),
    tslib_1.__param(3, (0, context_1.inject)(rest_1.RestBindings.Http.RESPONSE)),
    tslib_1.__param(4, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.FORM_URLENCODED]: {},
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, String, Object, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], SamlLoginController.prototype, "oktaSamlCallback", null);
exports.SamlLoginController = SamlLoginController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.AuthClientRepository)),
    tslib_1.__param(1, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(2, (0, context_1.inject)(providers_1.AuthCodeBindings.AUTH_CODE_GENERATOR_PROVIDER)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.AuthClientRepository, Object, Function])
], SamlLoginController);
//# sourceMappingURL=saml-login.controller.js.map