"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignupBearerVerifyProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const context_1 = require("@loopback/context");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const fs = tslib_1.__importStar(require("fs/promises"));
const jsonwebtoken_1 = require("jsonwebtoken");
const keys_1 = require("../keys");
let SignupBearerVerifyProvider = class SignupBearerVerifyProvider {
    constructor(logger, authConfig) {
        this.logger = logger;
        this.authConfig = authConfig;
    }
    value() {
        return async (token, req) => {
            var _a, _b;
            let result;
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            let publicKey; //NOSONAR
            try {
                if ((_a = this.authConfig) === null || _a === void 0 ? void 0 : _a.useSymmetricEncryption) {
                    result = (0, jsonwebtoken_1.verify)(token, process.env.JWT_SECRET, {
                        issuer: process.env.JWT_ISSUER,
                        algorithms: ['HS256'],
                    });
                }
                else {
                    publicKey = await fs.readFile((_b = process.env.JWT_PUBLIC_KEY) !== null && _b !== void 0 ? _b : '');
                    result = (0, jsonwebtoken_1.verify)(token, publicKey, {
                        issuer: process.env.JWT_ISSUER,
                        algorithms: ['RS256'],
                    });
                }
            }
            catch (error) {
                this.logger.error(JSON.stringify(error));
                throw new rest_1.HttpErrors.Unauthorized('TokenExpired');
            }
            return result;
        };
    }
};
exports.SignupBearerVerifyProvider = SignupBearerVerifyProvider;
exports.SignupBearerVerifyProvider = SignupBearerVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(1, (0, context_1.inject)(keys_1.AuthServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [Object, Object])
], SignupBearerVerifyProvider);
//# sourceMappingURL=bearer-verify.provider.js.map