"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CognitoAuthenticationProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const core_1 = require("@sourceloop/core");
const crypto_1 = tslib_1.__importDefault(require("crypto"));
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const repositories_1 = require("../repositories");
let CognitoAuthenticationProvider = class CognitoAuthenticationProvider {
    constructor(logger, refreshTokenRepo) {
        this.logger = logger;
        this.refreshTokenRepo = refreshTokenRepo;
    }
    value() {
        return async (refreshToken, req, payload) => {
            if (!req || !payload) {
                throw new Error('Payload information not provided');
            }
            return this.isAuthenticated(refreshToken, req, payload);
        };
    }
    async isAuthenticated(refreshToken, req, payload) {
        let isAuthenticated = true;
        const cognitoUrl = `${process.env.COGNITO_AUTH_CLIENT_DOMAIN}/oauth2/token`;
        const clientId = `${process.env.COGNITO_AUTH_CLIENT_ID}`;
        const clientSecret = `${process.env.COGNITO_AUTH_CLIENT_SECRET}`;
        const basicAuth = Buffer.from(`${clientId}:${clientSecret}`).toString('base64');
        const requestBody = `grant_type=refresh_token&client_id=${clientId}&refresh_token=${refreshToken}`;
        const refreshPayload = payload.refreshPayload;
        (0, node_fetch_1.default)(cognitoUrl, {
            method: 'POST',
            headers: {
                'Content-Type': core_1.CONTENT_TYPE.JSON,
                Authorization: `Basic ${basicAuth}`,
            },
            body: requestBody,
        })
            .then(response => response.json())
            .then(data => {
            refreshPayload.externalRefreshToken = data['refresh_token'];
        })
            .catch(error => {
            isAuthenticated = false;
            this.logger.error(`Error while generating access token. Error :: ${error} ${JSON.stringify(error)}`);
            return isAuthenticated;
        });
        const refreshTokenKey = crypto_1.default.randomBytes(32).toString('hex');
        await this.refreshTokenRepo.set(refreshTokenKey, refreshPayload, {
            ttl: payload.authClient.refreshTokenExpiration * 1000,
        });
        return isAuthenticated;
    }
};
exports.CognitoAuthenticationProvider = CognitoAuthenticationProvider;
exports.CognitoAuthenticationProvider = CognitoAuthenticationProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.RefreshTokenRepository)),
    tslib_1.__metadata("design:paramtypes", [Object, repositories_1.RefreshTokenRepository])
], CognitoAuthenticationProvider);
//# sourceMappingURL=cognito-authentication.provider.js.map