"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeycloakAuthenticationProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@sourceloop/core");
const base_64_1 = require("base-64");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
let KeycloakAuthenticationProvider = class KeycloakAuthenticationProvider {
    constructor(logger) {
        this.logger = logger;
    }
    value() {
        return async (accessToken) => this.isAuthenticated(accessToken);
    }
    isAuthenticated(accessToken) {
        let isAuthenticated = true;
        const params = new URLSearchParams();
        const strToEncode = `${process.env.KEYCLOAK_CLIENT_ID}:${process.env.KEYCLOAK_CLIENT_SECRET}`;
        const keycloakApiUrl = `${process.env.KEYCLOAK_HOST}/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/token/introspect`;
        params.append('token', accessToken);
        // Using fetch to make the API call
        (0, node_fetch_1.default)(keycloakApiUrl, {
            method: 'post',
            headers: {
                'Content-Type': core_1.CONTENT_TYPE.JSON,
                Authorization: `Basic ${(0, base_64_1.encode)(strToEncode)}`,
                Accept: 'application/json',
            },
            body: params,
        })
            .then(response => {
            // Check if the response status is OK (200)
            if (!response.ok) {
                throw new Error(`HTTP error! Status: ${response.status}`);
            }
            // Parse the JSON response
            return response.json();
        })
            .then(data => {
            if ('active' in data && data.active === false) {
                isAuthenticated = false;
            }
        })
            .catch(error => {
            this.logger.error(`Error while logging off from keycloak. Error :: ${error} ${JSON.stringify(error)}`);
        });
        return isAuthenticated;
    }
};
exports.KeycloakAuthenticationProvider = KeycloakAuthenticationProvider;
exports.KeycloakAuthenticationProvider = KeycloakAuthenticationProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [Object])
], KeycloakAuthenticationProvider);
//# sourceMappingURL=keycloak-authentication.provider.js.map